function fuzzySearch(needle, haystack) {
    let hlen = haystack.length;
    let nlen = needle.length;

    if (nlen > hlen) {
        return false;
    }
    if (nlen === hlen) {
        return needle === haystack;
    }

    outer: for (let i = 0, j = 0; i < nlen; i++) {
        let nch = needle.charCodeAt(i);

        while (j < hlen) {
            if (haystack.charCodeAt(j++) === nch) {
                continue outer;
            }
        }

        return false;
    }
    return true;
}

export default {

    data() {
        return {
            prompt: '',
            suggestion: false
        }
    },

    props: {
        fields: {
            type: Array,
            default: []
        },
    },

    computed: {
        suggestions() {

            if (!this.suggestion) return [];
            if (this.suggestion.value === ':') return this.fields;

            return this.fields.filter(field => fuzzySearch(this.suggestion.value, `:${field}`));
        }
    },

    mounted() {

        const textarea = this.$refs.prompt;

        textarea.addEventListener('keyup', evt => {

            const caretPosition = textarea.selectionStart;
            const textBeforeCaret = textarea.value.substring(0, caretPosition);
            const currentWord = textBeforeCaret.split(/\s+/).pop();

            if (!currentWord.startsWith(':')) {
                this.suggestion = false;
                return;
            }

            this.suggestion = {
                caretPosition,
                value: currentWord,
            };
        });

        textarea.addEventListener('keydown', evt => {

            const isEnter = evt.key == 'Enter' || evt.code == 'Enter';

            if (isEnter && (evt.metaKey || evt.ctrlKey)) {
                this.onSubmit();
                return;
            }

            if (this.suggestion && isEnter) {
                evt.preventDefault();
                this.selectSuggestion(this.suggestions[0]);
            }
        });
    },

    methods: {

        selectSuggestion(field) {

            if (!this.suggestion) return;

            const textarea = this.$refs.prompt;
            const caretPosition = this.suggestion.caretPosition;
            const textBeforeCaret = this.prompt.substring(0, caretPosition);

            const beforeMention = textBeforeCaret.substring(0, textBeforeCaret.lastIndexOf(':') + 1);
            const afterCaret = this.prompt.substring(caretPosition);
            this.prompt = `${beforeMention}${field} ${afterCaret}`;
            const newCaretPosition = beforeMention.length + field.length + 1;

            this.suggestion = false;

            setTimeout(() => {

                textarea.selectionStart = textarea.selectionEnd = newCaretPosition;
                textarea.focus();
            }, 50);
        },

        onSubmit() {
            this.$call('onSubmit', this.prompt);
            this.$close();
        }
    },

    template: /*html*/`
        <form class="kiss-position-relative" @submit.prevent="onSubmit">

            <div class="kiss-flex kiss-flex-middle">
                <div>
                    <kiss-svg class="kiss-color-primary" :src="$base('autopilot:icon.svg')" width="50" height="50"></kiss-svg>
                </div>
                <div class="kiss-flex-1 kiss-margin-left">
                    <span class="kiss-size-xsmall kiss-color-muted kiss-text-upper">{{ t('AI') }}</span>
                    <kiss-row class="kiss-flex-middle">
                        <div class="kiss-size-4 kiss-flex-1">
                            <span class="kiss-text-capitalize">{{ t('Prompt') }}</span>
                        </div>
                    </kiss-row>
                </div>
                <button type="button" :aria-label="t('Close')" class="kiss-input-blank kiss-cursor-pointer" kiss-dialog-close>
                    <kiss-svg class="kiss-color-muted" :src="$base('system:assets/icons/close.svg')" width="15"><canvas width="15" height="15"></canvas></kiss-svg>
                </button>
            </div>

            <textarea class="kiss-input kiss-margin" :placeholder="t('Instructions...')" v-model="prompt" style="min-height:120px;" ref="prompt"></textarea>

            <div class="kiss-margin-small-top kiss-flex kiss-flex-middle kiss-button-group">
                <button type="button" class="kiss-button-cancel kiss-button kiss-flex-1" kiss-dialog-close>{{ t('Cancel') }}</button>
                <button type="submit" class="kiss-button-confirm kiss-button kiss-button-primary kiss-flex-1" :disabled="!prompt.trim()">{{ t('Submit') }}</button>
            </div>

            <div class="kiss-position-bottom-left kiss-width-1-1 kiss-flex kiss-flex-wrap" gap="small" v-if="suggestion && suggestions.length" style="transform: translateY(calc(100% + (2 * var(--kiss-dialog-content-spacing))));">
                <button class="kiss-button kiss-button-small" :class="{'kiss-button-primary': idx === 0}" type="button" @click="selectSuggestion(field)" v-for="(field, idx) in suggestions">{{ field }}</button>
            </div>
        </form>
    `
}
