import {getGroupColor} from './utils.js';


let pickComponent = {

    data() {
        return {
            group: null,
            filter: '',
            clipboardComponent: null,
            preview: null,
            getGroupColor
        }
    },

    props: {
        components: {
            type: Object
        }
    },

    mounted() {
        this.clipboardComponent = JSON.parse(App.storage.get('layout.field.clipboard.component', 'null'));
    },

    computed: {

        filtered() {

            let components = {}, component = null;

            Object.keys(this.components || {}).sort((x, y) => {

                // sort components
                x = (this.components[x].label || x).toLocaleLowerCase();
                y = (this.components[y].label || y).toLocaleLowerCase();

                if (x < y) return -1;
                if (x > y) return 1;

                return 0;

            }).forEach(name => {

                if (this.filter && !`${name} ${this.components[name].label || ''}`.toLocaleLowerCase().includes(this.filter.toLocaleLowerCase())) {
                    return;
                }

                if (this.group && this.components[name].group != this.group ) return;
                components[name] = this.components[name]
            });

            return components;
        },

        groups() {
            let groups = [];

            Object.keys(this.components || {}).forEach(name => {
                if (!this.components[name].group || groups.indexOf(this.components[name].group) > -1) return;
                groups.push(this.components[name].group);
            });

            return groups.sort();
        },

        previewUrl() {

            const image = this.components[this.preview].image || null;

            if (!image || !image.file) {
                return null;
            }

            return `uploads://buckets/${image.bucket}/${image.file.path}`;
        }
    },

    methods: {
        select(component) {
            this.$call('select', component);
            this.$close();
        },

        showPreview(component) {

            const image = this.components[component].image || null;

            if (!image) {
                return;
            }

            if (this.hidePreviewIdle) {
                clearTimeout(this.hidePreviewIdle);
            }

            this.preview = component;
        },

        hidePreview() {

            if (!this.preview) {
                return;
            }

            this.hidePreviewIdle = setTimeout(() => this.preview = null, 300);
        },

        selectFromClipboard() {
            this.$call('selectFromClipboard', JSON.parse(JSON.stringify(this.clipboardComponent)));
            this.$close();
        }
    },

    template: /*html*/`
        <div class="app-offcanvas-container">

            <div class="kiss-padding kiss-size-4 kiss-text-bold kiss-flex kiss-flex-middle">
                <div class="kiss-margin-small-right">
                    <kiss-svg :src="$base('layout:assets/icons/component.svg')" width="40" height="40"></kiss-svg>
                </div>
                {{ t('Pick a component') }}
            </div>

            <kiss-card class="kiss-padding kiss-overlay-input kiss-flex-inline kiss-flex-middle">
                <div class="kiss-margin-small-right">
                    <icon class="kiss-size-1" :class="{'kiss-color-muted': !group, 'kiss-color-primary': group}">{{ !group ? 'dialpad' : 'workspaces' }}</icon>
                </div>
                <div>
                    <span class="kiss-text-caption kiss-color-muted">{{ t('Group') }}</span>
                    <div class="kiss-text-capitalize kiss-size-small" :class="{'kiss-color-muted': !group, 'kiss-text-bold': group}">{{ group || t('All components') }}</div>
                </div>
                <select v-model="group">
                    <option :value="null">{{ t('All components') }}</option>
                    <option :value="name" v-for="name in groups">{{ name }}</option>
                </select>
            </kiss-card>

            <div class="kiss-padding">
                <input type="text" class="kiss-input" :placeholder="t('Filter components...')" v-model="filter">
            </div>

            <div class="app-offcanvas-content kiss-padding">

                <kiss-grid cols="2@s 4@m" gap="small">

                        <kiss-card class="kiss-padding-small kiss-position-relative" theme="bordered" hover="contrast shadow" v-for="meta, component in filtered">
                            <kiss-row class="kiss-flex-middle" gap="small">
                                <div>
                                    <kiss-svg :src="$base(meta.icon)" width="35" height="35" :style="{color: getGroupColor(meta.group)}" v-if="meta.icon"></kiss-svg>
                                    <app-avatar size="35" :name="meta.label || component" :color="getGroupColor(meta.group)" v-if="!meta.icon"></app-avatar>
                                </div>
                                <div class="kiss-size-small kiss-flex-1">
                                    <div class="kiss-text-bold kiss-text-truncate">{{ meta.label || component }}</div>
                                    <div class="kiss-size-xsmall kiss-color-muted">{{ meta.group || '' }}</div>
                                </div>
                            </kiss-row>
                            <a class="kiss-cover" @click="select(component)" @mouseover="showPreview(component)" @mouseleave="hidePreview()" :title="meta.label || component"></a>
                        </kiss-card>

                </kiss-grid>

            </div>
            <div class="kiss-padding animated fadeIn" style="pointer-events:none;" v-if="preview">
                <div class="kiss-margin-small-top kiss-flex kiss-flex-center kiss-position-relative">
                    <display-image class="kiss-display-block kiss-margin-auto" :src="previewUrl" w="600" h="150"></display-image>
                </div>
            </div>
            <div class="kiss-padding" v-if="clipboardComponent">
                <button class="kiss-button kiss-width-1-1" @click="selectFromClipboard">{{ t('Paste copied component') }}</button>
            </div>

        </div>
    `
}

export default pickComponent;
