let PageTree = {

    name: 'page-tree',

    data() {
        return {
            loading: false
        }
    },

    props: {
        pages: {
            type: Array,
            default: []
        },
        level: {
            type: Number,
            default: 0
        },
        locale: {
            type: String,
            default: 'default'
        },
        p: {
            type: Object,
            default: null
        }
    },

    mounted() {

        if (this.p && this.p._children) {

            this.loading = true;

            let params = {_pid:this.p._id};

            if (this.locale && this.loacale !== 'default') {
                params.locale = this.locale;
            }

            this.$request('/pages/load', params).then(pages => {

                this.p.children = pages;
                this.loading = false;
            }).catch(res => {
                this.loading = false;
                App.ui.notify(res.error || 'Loading children failed!', 'error');
            });
        }
    },

    template: /*html*/`
        <div>
            <app-loader size="small" v-if="loading"></app-loader>

            <div v-if="!loading">
                <div v-for="page in pages">
                    <div class="kiss-margin-xsmall">
                        <kiss-card class="kiss-flex kiss-flex-middle kiss-padding-xsmall kiss-margin-xsmall kiss-visible-toggle" theme="bordered shadowed" hover="contrast">
                            <a class="kiss-margin-small-right kiss-color-muted" :class="{'kiss-hidden': !page._children}" :placeholder="t('Toggle children')" @click="page._showChildren = !page._showChildren">
                                <icon>{{ page._showChildren ? 'indeterminate_check_box' : 'add_box' }}</icon>
                            </a>
                            <div class="kiss-margin-small-right">
                                <icon :class="{'kiss-color-danger': !page._state, 'kiss-color-success': page._state === 1}">circle</icon>
                            </div>
                            <div class="kiss-flex-1 kiss-size-small kiss-text-truncate" :class="{'kiss-text-bold': page._children}">
                                {{ page.title }}
                            </div>
                            <a class="kiss-invisible-hover kiss-size-5 kiss-badge" @click="select(page)"><icon>link</icon></a>
                        </kiss-card>
                        <div v-if="page._showChildren || !page._children" :style="{paddingLeft: (((level+1)*24)+'px')}">
                            <page-tree class="pages-tree" :pages="page.children" :level="level+1" :p="page" :locale="locale" @pickPage="pickedPage"></page-tree>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    `,

    methods: {

        pickedPage(data) {
            this.select(data.page)
        },

        select(page) {
            this.$emit('pick-page', {page})
        }
    }
}

export default {

    data() {
        return {
            pages: [],
            loading: false,
            i18n: this.locale || 'default'
        }
    },

    props: {
        locale: {
            type: String,
            default: 'default'
        }
    },

    components: {
        PageTree
    },

    mounted() {
        this.load()
    },

    watch: {
        i18n() {
            this.load();
        }
    },

    template: /*html*/`
        <div class="app-offcanvas-container">
            <div class="kiss-padding kiss-text-bold kiss-flex kiss-flex-middle">
                <div class="kiss-margin-small-right"><icon size-larger>link</icon></div>
                <div class="kiss-flex-1 kiss-margin-small-right">{{ t('Select page') }}</div>
                <div class="kiss-overlay-input" v-if="Object.keys(App._locales).length > 1">
                    <button class="kiss-button kiss-button-small" type="button">{{ App._locales[i18n] }}</button>
                    <select v-model="i18n"><option :value="vi18n" v-for="(label,vi18n) in App._locales">{{label}}</option></select>
                </div>
            </div>
            <div class="app-offcanvas-content kiss-padding kiss-bgcolor-contrast">
                <app-loader size="small" v-if="loading"></app-loader>
                <page-tree :pages="pages" :locale="i18n" v-if="!loading" @pickPage="select"></page-tree>
            </div>
        </div>
    `,

    methods: {
        select(data) {
            this.$call('select', data.page, this.i18n);
            this.$close();
        },

        load() {

            this.loading = true;

            this.$request('/pages/load', {_pid:{}, locale: this.i18n}).then(pages => {
                this.pages = pages;
                this.loading = false;
            }).catch(res => {
                this.loading = false;
                App.ui.notify(res.error || 'Loading failed!', 'error');
            });
        }
    }
}
